Avoid checking to see if a bool is less than zero.
Create a symbolic name for -1 when it means "don't know, probe at runtime".



git-svn-id: http://skia.googlecode.com/svn/trunk@1606 2bbb7eff-a529-9590-31e7-b0007b416f81
diff --git a/gpu/include/GrGLInterface.h b/gpu/include/GrGLInterface.h
index 1a3dade..5802ec4 100644
--- a/gpu/include/GrGLInterface.h
+++ b/gpu/include/GrGLInterface.h
@@ -205,6 +205,10 @@
     typedef GrGLvoid (GR_GL_FUNCTION_TYPE *GrGLBindFragDataLocationIndexedProc)(GrGLuint program, GrGLuint colorNumber, GrGLuint index, const GrGLchar * name);
 }  // extern "C"
 
+enum GrGLBug {
+    kProbe_GrGLBug = -1
+};
+
 /*
  * The following interface exports the OpenGL entry points used by the system.
  * Use of OpenGL calls is disallowed.  All calls should be invoked through
@@ -222,12 +226,12 @@
     GrGLBinding fBindingsExported;
 
     /// Does this GL support NPOT textures on FBOs?
     /// boolean value, or -1 to probe (slowly) at context creation.
     int fNPOTRenderTargetSupport;
 
     /// Some GL implementations (PowerVR SGX devices like the iPhone 4)
     /// have restrictions on the size of small render targets.
     /// -1 to probe (slowly) at context creation.
     int fMinRenderTargetHeight;
     int fMinRenderTargetWidth;
@@ -222,12 +226,12 @@
 
     /// Does this GL support NPOT textures on FBOs?
-    /// boolean value, or -1 to probe (slowly) at context creation.
+    /// boolean value, or kProbe_GrGLBug to probe (slowly) at context creation.
     int fNPOTRenderTargetSupport;
 
@@ -222,12 +226,12 @@
     /// Some GL implementations (PowerVR SGX devices like the iPhone 4)
     /// have restrictions on the size of small render targets.
-    /// -1 to probe (slowly) at context creation.
+    /// kProbe_GrGLBug to probe (slowly) at context creation.
     int fMinRenderTargetHeight;
     int fMinRenderTargetWidth;